@@ -126,3 +126,6 @@ class Dataset(BaseDataset, RawDataset, ABC):
             filename: only valid if kind=DataKind.MMAP_FILE
         """
         super().__init__(data, kind, transform, filename)
+
+    def __getitem__(self, index):
+        return self.get(index)
