@@ -76,11 +76,11 @@ class RawDataset:
     def __len__(self) -> int:
         return self.n_data
 
-    def __getitem__(self, index: int):
+    def get(self, index: int):
         data = None
 
         if index < 0:
-            index = self.n_data + index
+            index += self.n_data
 
         if self.kind == DataKind.MEM_SEQ:
             data = self.data[index]
@@ -102,7 +102,7 @@ class RawDataset:
                 line = self.data[start:]
 
             try:
-                data = bytes_to_str(line).strip('\n')
+                data = bytes_to_str(line).split('\n')[0].strip('\n')
             except Exception as e:
                 logger.error(f'decode failed: index={index}, offset={self.offset[index]}, line={line}')
                 raise e
@@ -110,3 +110,6 @@ class RawDataset:
         data = apply_transform(self.transform, data)
 
         return data
+
+    def __getitem__(self, index: int):
+        return self.get(index)
